@@ -8,7 +8,7 @@ return(answer)}
 
 
 "describeBy" <-
-function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
+function (x,group=NULL,mat=FALSE,type=3,digits=15,...) {               #data are x, grouping variable is group
 if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
 		answer <- by(x,group,describe,type=type,...)
@@ -51,7 +51,7 @@ if (mat) { ncol <- length(answer[[1]])  #the more complicated case. How to reord
 	  	rn[k] <- paste(row.names[var],group,sep="")
 	    #mat.ans[k,1] <- group
 	    for (stat in 1:n.col) {if(!is.null(answer[[group]][[stat]][var])) {
-	   	 mat.ans[k,stat] <- answer[[group]][[stat]][var]} else { mat.ans[k,stat] <- NA }
+	   	 mat.ans[k,stat] <- round(answer[[group]][[stat]][var],digits)} else { mat.ans[k,stat] <- NA }
 	   	  } 
 	     k <- k + 1}
 	   }
